:mod:`euphorie.client.browser.survey`
=====================================

.. automodule:: euphorie.client.browser.survey
   :members:

Views
-----

.. autoclass:: SurveySessionsView
   :members:

.. autoclass:: DefaultIntroductionView
   :members:

